@@ -65,7 +65,7 @@ while test $# -gt 0; do
 		echo_exec_prefix=true
 		;;
 	--version)
-		echo VERSION=9.13.0
+		echo VERSION=9.13.5
 		exit 0
 		;;
 	--cflags)
@@ -120,7 +120,7 @@ if test x"$echo_cflags" = x"true"; then
 		includes="-I${includedir}"
 	fi
 	if test x"$libisc" = x"true"; then
-		includes="$includes -D_REENTRANT   -D_GNU_SOURCE "
+		includes="$includes    "
 	fi
 	echo $includes
 fi
@@ -146,11 +146,11 @@ if test x"$echo_libs" = x"true"; then
 		libs="$libs -lisccc"
 	fi
 	if test x"$libisc" = x"true" ; then
-		libs="$libs -lisc  -lcrypto"
+		libs="$libs -lisc -L/usr/lib -lcrypto"
 		needothers=true
 	fi
 	if test x"$needothers" = x"true" ; then
-		libs="$libs  -ldl -lcap -ljson-c -lpthread -lm -lGeoIP  -L/usr/lib -lxml2 -lz -llzma -licui18n -licuuc -licudata -lm -ldl "
+		libs="$libs  -ljson-c -llmdb  -lm -lGeoIP  -L/usr/lib -lxml2 -lz -llzma -licui18n -licuuc -licudata -lm -ldl "
 	fi
 	echo $libs
 fi
